Learn R Programming

ksm (version 1.0)

kdens_smlnorm: Symmetric matrix log-normal kernel density

Description

Given a sample of m points xs from an original sample and a set of n new sample matrices x at which to evaluate the symmetric matrix normal log kernel, return the density with bandwidth parameter b.

Usage

kdens_smlnorm(x, xs, b, log = TRUE)

Value

a vector of length n containing the (log) density of the sample x

Arguments

x

cube of size d by d by n of points at which to evaluate the density

xs

cube of size d by d by m of sample matrices which are used to construct the kernel

b

positive double giving the bandwidth parameter

log

bool; if TRUE, return the log density