Given a sample of m points xs from an original sample
and a set of n new sample symmetric positive definite matrices x at which to evaluate the kernel, return the density with bandwidth parameter b.
kdens_symmat(x, xs, kernel = "Wishart", b = 1, log = TRUE)a vector of length n containing the (log) density of the sample x
cube of size d by d by n of points at which to evaluate the density
cube of size d by d by m of sample matrices which are used to construct the kernel
string, one of Wishart, smnorm or smlnorm.
positive double giving the bandwidth parameter
bool; if TRUE, return the log density