Learn R Programming

ksm (version 1.0)

lcv_kdens_symmat: Likelihood cross-validation for symmetric positive definite matrix kernels

Description

Given a cube of sample observations (consisting of random symmetric positive definite matrices), and a vector of candidate bandwidth parameters b, compute the leave-one-out likelihood cross-validation criterion and return the bandwidth among the choices that minimizes the criterion.

Usage

lcv_kdens_symmat(x, b, kernel = "Wishart")

Value

a list with arguments

  • lcv vector of likelihood cross validation criterion

  • b vector of candidate bandwidth

  • bandwidth optimal bandwidth among candidates

  • kernel string indicating the choice of kernel function

Arguments

x

array of dimension d by d by n

b

vector of candidate bandwidth, strictly positive

kernel

string indicating the kernel, one of Wishart or smlnorm.