Learn R Programming

ksm (version 1.0)

lcv_kern_Wishart: Likelihood cross validation criterion for Wishart kernel

Description

Given a cube x and a bandwidth b, compute the leave-one-out cross validation criterion by taking out a slice and evaluating the kernel at the holdout value.

Usage

lcv_kern_Wishart(x, b)

Value

the value of the log objective function

Arguments

x

[cube] array of dimension d by d by n

b

[numeric] scale parameter, strictly positive