lcv_kern_smnorm: Likelihood cross validation criterion for symmetric matrix normal kernel
Description
Given a cube x and a bandwidth b, compute
the leave-one-out cross validation criterion by taking out a slice
and evaluating the kernel at the holdout value.