Learn R Programming

ksm (version 1.0)

lscv_kern_smlnorm: Least square cross validation criterion for log symmetric matrix normal kernel

Description

Finite sample h-block leave-one-out approximation to the least square criterion, omitting constant term. Only pairs that are \(|i-j| \leq h\) apart are considered.

Usage

lscv_kern_smlnorm(x, b, h = 1L)

Value

a vector of length two containing the log of the summands

Arguments

x

[cube] array of dimension d by d by n

b

[numeric] scale parameter, strictly positive

h

[int] integer indicating the separation lag