Given a target density and a kernel estimator, evaluate the integrated squared error by Monte Carlo integration by simulating from uniform variates on the hypercube.
simu_ise_montecarlo(x, b, kernel, model, B = 10000L, delta = 0.001)a vector of length 2 containing the mean and the standard deviation of the estimator.
a cube of dimension d by d by n containing the sample matrices which define the kernel matrix estimator
positive double, bandwidth parameter
integer between 1 and 6 indicating the simulation scenario
number of Monte Carlo replications, default to 10K
double less than 1; the integrals on \([0, \infty)\) are truncated to \([\delta, 1/\delta]\).