Given a sample of m points xs from an original sample
and a set of n new sample matrices x at which to evaluate the symmetric matrix normal log kernel, return the density with bandwidth parameter b.
kdens_smlnorm(x, xs, b, log = TRUE)a vector of length n containing the (log) density of the sample x
cube of size d by d by n of points at which to evaluate the density
cube of size d by d by m of sample matrices which are used to construct the kernel
positive double giving the bandwidth parameter
bool; if TRUE, return the log density