Given a cube of sample observations (consisting of random symmetric positive definite matrices), and a vector of candidate bandwidth parameters b,
compute the leave-one-out likelihood cross-validation criterion and
return the bandwidth among the choices that minimizes the criterion.
lcv_kdens_symmat(x, b, kernel = "Wishart")a list with arguments
lcv vector of likelihood cross validation criterion
b vector of candidate bandwidth
bandwidth optimal bandwidth among candidates
kernel string indicating the choice of kernel function
array of dimension d by d by n
vector of candidate bandwidth, strictly positive
string indicating the kernel, one of Wishart or smlnorm.