powered by
Given a cube x and a bandwidth b, compute the leave-one-out cross validation criterion by taking out a slice and evaluating the kernel at the holdout value.
x
b
lcv_kern_Wishart(x, b)
the value of the log objective function
[cube] array of dimension d by d by n
d
n
[numeric] scale parameter, strictly positive