Finite sample h-block leave-one-out approximation to the least square criterion, omitting constant term. Only pairs that are \(|i-j| \leq h\) apart are considered.
lscv_kern_smlnorm(x, b, h = 1L)a vector of length two containing the log of the summands
[cube] array of dimension d by d by n
[numeric] scale parameter, strictly positive
[int] integer indicating the separation lag