Given a vector of points x and an order p, compute the multivariate gamma function. The function is defined as
$$\gamma_p(x) = \pi^{p(p-1)/4}\prod_{i=1}^p \Gamma\{x + (1-i)/2\}.$$
mgamma(x, p, log = FALSE)a matrix with one column of the same length as x
[vector] of points at which to evaluate the function
[int] dimension of the multivariate gamma function, strictly positive.
[logical] if TRUE, returns the log multivariate gamma function.