rmbeta2: Random matrix generation from matrix beta type II distribution
Description
This function only supports the case of diagonal matrices
Usage
rmbeta2(n, d, shape1, shape2)
Value
a cube of dimension d by d by n
Arguments
- n
sample size
- d
dimension of the matrix
- shape1
positive shape parameter, strictly larger than \((d-1)/2\).
- shape2
positive shape parameter, strictly larger than \((d-1)/2\).